==> ns3-3.24.1.txz: usr/local/include/ns3.24.1/ns3/internet-module.h <==

#ifdef NS3_MODULE_COMPILATION
# error "Do not include ns3 module aggregator headers from other modules; these are meant only for end user scripts."
#endif

#ifndef NS3_MODULE_INTERNET
    

// Module headers:
#include "arp-cache.h"
#include "arp-header.h"
#include "arp-l3-protocol.h"
#include "candidate-queue.h"
#include "codel-queue.h"
#include "global-route-manager-impl.h"
#include "global-route-manager.h"
#include "global-router-interface.h"
#include "icmpv4-l4-protocol.h"
#include "icmpv4.h"
#include "icmpv6-header.h"
#include "icmpv6-l4-protocol.h"
#include "internet-stack-helper.h"
#include "internet-trace-helper.h"
#include "ip-l4-protocol.h"
#include "ipv4-address-generator.h"
#include "ipv4-address-helper.h"
#include "ipv4-global-routing-helper.h"
#include "ipv4-global-routing.h"
#include "ipv4-header.h"
#include "ipv4-interface-address.h"
#include "ipv4-interface-container.h"
#include "ipv4-interface.h"
#include "ipv4-l3-protocol.h"
#include "ipv4-list-routing-helper.h"
#include "ipv4-list-routing.h"
#include "ipv4-packet-info-tag.h"
#include "ipv4-packet-probe.h"
#include "ipv4-raw-socket-factory.h"
#include "ipv4-raw-socket-impl.h"
#include "ipv4-route.h"
#include "ipv4-routing-helper.h"
#include "ipv4-routing-protocol.h"
#include "ipv4-routing-table-entry.h"
#include "ipv4-static-routing-helper.h"
#include "ipv4-static-routing.h"
#include "ipv4.h"
#include "ipv6-address-generator.h"
#include "ipv6-address-helper.h"
#include "ipv6-extension-demux.h"
#include "ipv6-extension-header.h"
#include "ipv6-extension.h"
#include "ipv6-header.h"
#include "ipv6-interface-address.h"
#include "ipv6-interface-container.h"
#include "ipv6-interface.h"
#include "ipv6-l3-protocol.h"
#include "ipv6-list-routing-helper.h"
#include "ipv6-list-routing.h"
#include "ipv6-option-header.h"
#include "ipv6-packet-info-tag.h"
#include "ipv6-packet-probe.h"
#include "ipv6-pmtu-cache.h"
#include "ipv6-raw-socket-factory.h"
#include "ipv6-route.h"
#include "ipv6-routing-helper.h"
#include "ipv6-routing-protocol.h"
#include "ipv6-routing-table-entry.h"
#include "ipv6-static-routing-helper.h"
#include "ipv6-static-routing.h"
#include "ipv6.h"
#include "loopback-net-device.h"
#include "ndisc-cache.h"
#include "ripng-header.h"
#include "ripng-helper.h"
#include "ripng.h"
#include "rtt-estimator.h"
#include "tcp-header.h"
#include "tcp-l4-protocol.h"
#include "tcp-newreno.h"
#include "tcp-option.h"
#include "tcp-reno.h"
#include "tcp-rfc793.h"
#include "tcp-rx-buffer.h"
#include "tcp-socket-base.h"
#include "tcp-socket-factory.h"
#include "tcp-socket.h"
#include "tcp-tahoe.h"
#include "tcp-tx-buffer.h"
#include "tcp-westwood.h"
#include "udp-header.h"
#include "udp-l4-protocol.h"
#include "udp-socket-factory.h"
#include "udp-socket.h"
#endif

==> ns3-3.33.txz: usr/local/include/ns3.33/ns3/internet-module.h <==

#ifdef NS3_MODULE_COMPILATION
# error "Do not include ns3 module aggregator headers from other modules; these are meant only for end user scripts."
#endif

#ifndef NS3_MODULE_INTERNET
    

// Module headers:
#include "arp-cache.h"
#include "arp-header.h"
#include "arp-l3-protocol.h"
#include "arp-queue-disc-item.h"
#include "candidate-queue.h"
#include "global-route-manager-impl.h"
#include "global-route-manager.h"
#include "global-router-interface.h"
#include "icmpv4-l4-protocol.h"
#include "icmpv4.h"
#include "icmpv6-header.h"
#include "icmpv6-l4-protocol.h"
#include "internet-stack-helper.h"
#include "internet-trace-helper.h"
#include "ip-l4-protocol.h"
#include "ipv4-address-generator.h"
#include "ipv4-address-helper.h"
#include "ipv4-end-point-demux.h"
#include "ipv4-end-point.h"
#include "ipv4-global-routing-helper.h"
#include "ipv4-global-routing.h"
#include "ipv4-header.h"
#include "ipv4-interface-address.h"
#include "ipv4-interface-container.h"
#include "ipv4-interface.h"
#include "ipv4-l3-protocol.h"
#include "ipv4-list-routing-helper.h"
#include "ipv4-list-routing.h"
#include "ipv4-packet-filter.h"
#include "ipv4-packet-info-tag.h"
#include "ipv4-packet-probe.h"
#include "ipv4-queue-disc-item.h"
#include "ipv4-raw-socket-factory.h"
#include "ipv4-raw-socket-impl.h"
#include "ipv4-route.h"
#include "ipv4-routing-helper.h"
#include "ipv4-routing-protocol.h"
#include "ipv4-routing-table-entry.h"
#include "ipv4-static-routing-helper.h"
#include "ipv4-static-routing.h"
#include "ipv4.h"
#include "ipv6-address-generator.h"
#include "ipv6-address-helper.h"
#include "ipv6-end-point-demux.h"
#include "ipv6-end-point.h"
#include "ipv6-extension-demux.h"
#include "ipv6-extension-header.h"
#include "ipv6-extension.h"
#include "ipv6-header.h"
#include "ipv6-interface-address.h"
#include "ipv6-interface-container.h"
#include "ipv6-interface.h"
#include "ipv6-l3-protocol.h"
#include "ipv6-list-routing-helper.h"
#include "ipv6-list-routing.h"
#include "ipv6-option-header.h"
#include "ipv6-option.h"
#include "ipv6-packet-filter.h"
#include "ipv6-packet-info-tag.h"
#include "ipv6-packet-probe.h"
#include "ipv6-pmtu-cache.h"
#include "ipv6-queue-disc-item.h"
#include "ipv6-raw-socket-factory.h"
#include "ipv6-route.h"
#include "ipv6-routing-helper.h"
#include "ipv6-routing-protocol.h"
#include "ipv6-routing-table-entry.h"
#include "ipv6-static-routing-helper.h"
#include "ipv6-static-routing.h"
#include "ipv6.h"
#include "loopback-net-device.h"
#include "ndisc-cache.h"
#include "rip-header.h"
#include "rip-helper.h"
#include "rip.h"
#include "ripng-header.h"
#include "ripng-helper.h"
#include "ripng.h"
#include "rtt-estimator.h"
#include "tcp-bic.h"
#include "tcp-congestion-ops.h"
#include "tcp-cubic.h"
#include "tcp-dctcp.h"
#include "tcp-header.h"
#include "tcp-highspeed.h"
#include "tcp-htcp.h"
#include "tcp-hybla.h"
#include "tcp-illinois.h"
#include "tcp-l4-protocol.h"
#include "tcp-ledbat.h"
#include "tcp-linux-reno.h"
#include "tcp-lp.h"
#include "tcp-option-rfc793.h"
#include "tcp-option-sack-permitted.h"
#include "tcp-option-sack.h"
#include "tcp-option-ts.h"
#include "tcp-option-winscale.h"
#include "tcp-option.h"
#include "tcp-prr-recovery.h"
#include "tcp-rate-ops.h"
#include "tcp-recovery-ops.h"
#include "tcp-rx-buffer.h"
#include "tcp-scalable.h"
#include "tcp-socket-base.h"
#include "tcp-socket-factory.h"
#include "tcp-socket-state.h"
#include "tcp-socket.h"
#include "tcp-tx-buffer.h"
#include "tcp-tx-item.h"
#include "tcp-vegas.h"
#include "tcp-veno.h"
#include "tcp-westwood.h"
#include "tcp-yeah.h"
#include "udp-header.h"
#include "udp-l4-protocol.h"
#include "udp-socket-factory.h"
#include "udp-socket.h"
#endif
